@@ -5,10 +5,9 @@ use warnings;
 
 use base 'Devel::Declare::MethodInstaller::Simple';
 use Method::Signatures::Parser;
-use Data::Alias;
 use Devel::Pragma qw(my_hints);
 
-our $VERSION = '20121219.0033_001';
+our $VERSION = '20130216.1729_001';
 
 our $DEBUG = $ENV{METHOD_SIGNATURES_DEBUG} || 0;
 
@@ -989,17 +988,18 @@ sub inject_from_signature {
 
     if( @{$signature->{named}} ) {
         my $first_named_idx = @{$signature->{positional}};
+        require Data::Alias;
         push @code, "Data::Alias::alias( my (\%args) = \@_[$first_named_idx..\$#_] );";
 
         for my $sig (@{$signature->{named}}) {
             push @code, $self->inject_for_sig($sig);
         }
 
-        push @code, $class . '->named_param_error(\%args) if %args;'
+        push @code, $class . '->named_param_error(\%args) if keys %args;'
             if $signature->{overall}{num_named} && !$signature->{overall}{yadayada};
     }
 
-    push @code, $class . '->named_param_error(\%args) if %args;' if $signature->{overall}{has_named};
+    push @code, $class . '->named_param_error(\%args) if keys %args;' if $signature->{overall}{has_named};
 
     my $max_argv = $signature->{overall}{max_argv_size};
     my $max_args = $signature->{overall}{max_args};
@@ -1098,6 +1098,7 @@ sub inject_for_sig {
 
     # Handle \@foo
     if ( $sig->{is_ref_alias} or $sig->{traits}{alias} ) {
+        require Data::Alias;
         push @code, sprintf 'Data::Alias::alias(%s = %s);', $lhs, $rhs;
     }
     # Handle "is ro"
@@ -1157,6 +1158,14 @@ sub inject_for_type_check
     }
 }
 
+# This class method just dies with the message generated by signature_error.
+# If necessary it can be overridden by a subclass to do something fancier.
+#
+sub signature_error_handler {
+    my ($class, $msg) = @_;
+    die $msg;
+}
+
 # This is a common function to throw errors so that they appear to be from the point of the calling
 # sub, not any of the Method::Signatures subs.
 sub signature_error {
@@ -1164,7 +1173,7 @@ sub signature_error {
     my $class = ref $proto || $proto;
 
     my ($file, $line, $method) = carp_location_for($class);
-    die "In call to $method(), $msg at $file line $line.\n";
+    $class->signature_error_handler("In call to $method(), $msg at $file line $line.\n");
 }
 
 sub required_arg {
@@ -1368,11 +1377,28 @@ C<signature_error>, which your versions should do as well.
 
 =head2 signature_error
 
-This is a class method which calls C<die> and reports the error as
-being from the caller's perspective.  Most likely you will not need to
-override this.  If you'd like to have Method::Signatures errors give
-full stack traces (similar to C<$Carp::Verbose>), have a look at
-L<Carp::Always>.
+This is a class method which calls C<signature_error_handler> (see
+below) and reports the error as being from the caller's perspective.
+Most likely you will not need to override this.  If you'd like to have
+Method::Signatures errors give full stack traces (similar to
+C<$Carp::Verbose>), have a look at L<Carp::Always>.
+
+=head2 signature_error_handler
+
+By default, C<signature_error> generates an error message and
+C<die>s with that message.  If you need to do something fancier with
+the generated error message, your subclass can define its own
+C<signature_error_handler>.  For example:
+
+    package My::Method::Signatures;
+
+    use Moose;
+    extends 'Method::Signatures';
+
+    sub signature_error_handler {
+        my ($class, $msg) = @_;
+        die bless { message => $msg }, 'My::ExceptionClass';
+    };
 
 =head2 type_check
 
@@ -1401,6 +1427,27 @@ If you want to write "use Method::Signatures" in a one-liner, do a
 C<-MMethod::Signatures> first.  This is due to a bug/limitation in
 Devel::Declare.
 
+=head2 Close parends in comments
+
+Because of the way L<Devel::Declare> parses things, a close parend
+inside a comment could throw off the signature parsing.  For instance:
+
+    func foo (
+        $foo,       # $foo might contain )
+        $bar
+    )
+
+is going to produce a syntax error, because the parend inside the
+comment is perceived as the end of the signature.  On the other hand,
+this:
+
+    func foo (
+        $foo,       # (this is the $foo parend)
+        $bar
+    )
+
+is fine, because the parends in the comments are balanced.
+
 =head2 No source filter
 
 While this module does rely on the black magic of L<Devel::Declare> to
